@@ -1,7 +1,8 @@
 from .log import logger_group
 from .client import *
 from .api import (
-    MessageDirection, Api, ResizingMethod, RoomVisibility, RoomPreset
+    MessageDirection, Api, ResizingMethod, RoomVisibility, RoomPreset,
+    PushRuleKind,
 )
 from .responses import *
 from .events import *
